@@ -52,6 +52,7 @@
 #include <webkit2/WebKitWebInspector.h>
 #include <webkit2/WebKitWebResource.h>
 #include <webkit2/WebKitWebViewBase.h>
+#include <webkit2/WebKitWebViewSessionState.h>
 #include <webkit2/WebKitWindowProperties.h>
 
 G_BEGIN_DECLS
@@ -276,6 +277,9 @@ webkit_web_view_new_with_user_content_manager        (WebKitUserContentManager
 WEBKIT_API WebKitWebContext *
 webkit_web_view_get_context                          (WebKitWebView             *web_view);
 
+WEBKIT_API void
+webkit_web_view_try_close                            (WebKitWebView             *web_view);
+
 WEBKIT_API void
 webkit_web_view_load_uri                             (WebKitWebView             *web_view,
                                                       const gchar               *uri);
@@ -502,6 +506,13 @@ webkit_web_view_set_editable                         (WebKitWebView
 WEBKIT_API WebKitEditorState *
 webkit_web_view_get_editor_state                     (WebKitWebView             *web_view);
 
+WEBKIT_API WebKitWebViewSessionState *
+webkit_web_view_get_session_state                    (WebKitWebView             *web_view);
+
+WEBKIT_API void
+webkit_web_view_restore_session_state                (WebKitWebView             *web_view,
+                                                      WebKitWebViewSessionState *state);
+
 G_END_DECLS
 
 #endif
